@@ -20,6 +20,8 @@
  *         Mattias Bengtsson <mattias.jc.bengtsson@gmail.com>
  */
 
+const _ = imports.gettext.gettext;
+
 const GLib = imports.gi.GLib;
 const GObject = imports.gi.GObject;
 const Geocode = imports.gi.GeocodeGlib;
@@ -213,6 +215,25 @@ var PlaceEntry = GObject.registerClass({
             parsed = true;
         }
 
+        if (this.text.startsWith('http://') ||
+            this.text.startsWith('https://')) {
+            if (this._cancellable)
+                this._cancellable.cancel();
+            this._cancellable = null;
+            Place.parseHttpURL(this.text, (place, error) => {
+                if (place)
+                    this.place = place;
+                else
+                    Utils.showDialog(error,
+                                     Gtk.MessageType.ERROR, this.get_toplevel());
+            });
+
+            /* don't cancel ongoing search, as we have started an async
+             * operation looking up the OSM object
+             */
+            return true;
+        }
+
         if (parsed && this._cancellable)
             this._cancellable.cancel();
 
